#
# spec file for package apache2-mod_tidy
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


########################################
# apache macros
########################################
%define modname mod_tidy
Name:           apache2-mod_tidy
Version:        0.5.5
Release:        219.9
###
###
Summary:        Apache Module using the Tidy Library to Clean Up HTML, XHTML, and XML
License:        Apache-2.0
Group:          Productivity/Networking/Web/Utilities
Url:            http://mod-tidy.sourceforge.net/
Source0:        http://mod-tidy.sourceforge.net/src/mod_tidy-%{version}.tar.gz
Source1:        %{modname}-suse-addons.tar.bz2
BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-devel
BuildRequires:  libtidy-devel
Requires:       %{apache_mmn}
Requires:       %{apache_suse_maintenance_mmn}
Requires:       apache2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
mod_tidy is a module for Apache that works as a filter that hooks
itself to HTML output.	mod_tidy feeds the HTML output to TidyLib
(http://tidy.sourceforge.net/), which validates the HTML output.  If
TidyLib finds an error, the client receives a HTML page with a list of
all found errors. If TidyLib does not complain, you get your HTML data
as without mod_tidy.

To load the module into Apache, run the command "a2enmod tidy" as root.

To learn about the configuration, refer to
%{_docdir}/apache2-mod_tidy/README.

%prep
%setup -q -n %{modname}-%{version} -a 1

%build
# APR uses pre-installed TidyLib instead of the packaged one
export CFLAGS="$CFLAGS -I%{_includedir}/tidy"
export CPPFLAGS="$CPPFLAGS -I%{_includedir}/tidy"
%{apache_apxs} -I%{_includedir}/tidy \
         -c src/%{modname}.c \
	 -ltidy
%configure --with-apxs=%{apache_apxs} \
           --with-tidy=%{_libdir}
# RPM_OPT_FLAGS come from apxs
make OPT="%{apache_cflags}" %{?_smp_mflags}

%install
install -Dpm 755 src/.libs/mod_tidy.so %{buildroot}%{apache_libexecdir}/%{modname}.so
install -Dpm 644 mod_tidy.conf %{buildroot}%{apache_sysconfdir}/%{modname}.conf
mv %{modname}-suse-addons/README.SUSE .

%post
echo "
To load %{modname} into Apache, add tidy to APACHE_MODULES in %{_sysconfdir}/sysconfig/apache2.
Please read %{_defaultdocdir}/%{name}/README.SUSE for further configuration hints.
Finally, restart the webserver with 'rcapache2 graceful'.
"

%check
set +x
%apache_test_module_load -m tidy:filter -i mod_tidy.conf
set -x

%files
%defattr(-, root, root)
%doc Changes INSTALL LICENSE README*
%config(noreplace) %{apache_sysconfdir}/%{modname}.conf
%attr(755, root, root) %{apache_libexecdir}/%{modname}.so

%changelog
* Fri Sep  4 2015 kstreitova@suse.com
- test module with %%apache_test_module_load
* Thu Jul 16 2015 pgajdos@suse.com
- Requries: %%{apache_suse_maintenance_mmn}
  This will pull this module to the update (in released distribution)
  when apache maintainer thinks it is good (due api/abi changes).
* Sun Nov  9 2014 ledest@gmail.com
- post script: remove '-e' option of 'echo' command that may be
  unsupported in some POSIX-complete shells
* Mon Nov  3 2014 pgajdos@suse.com
- call spec-cleaner
- use apache rpm macros
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Mon Nov 13 2006 poeml@suse.de
- copy package to autobuild, adding .changes file
- remove #neededforbuild
- fix buildrequires (don't work with commas)
* Sun Nov 12 2006 sierkb@gmx.de
- Spec file cleanup: added libtidy to REQUIRED.
- Spec file cleanup: made email adresses more obfuscated against Spam.
* Mon Jan 30 2006 sierkb@gmx.de
- mod_tidy.c:
    Added compile variable MODULE_RELEASE;
    Replaced Tabs with white spaces;
    Replaced deprecated // comments with /**/.
- /tidy/include/platform.h:
    Added patch #11012006knauf (Netware convenience patch).
* Wed Jan 25 2006 sierkb@gmx.de
- Update to version 0.5.5:
  - Made mod_tidy ready for Apache 2.2 (APR 1.x):
  - Iteration over a brigade with the macro APR_BRIGADE_FOREACH is deprecated
    since apr-util 0.9.x.
    Since apr-util 1.x, which is used by Apache 2.2, iteration over a brigade
    has to be done in a different way
    (see http://www.apachetutor.org/dev/brigades).
* Sat Dec 31 2005 sierkb@gmx.de
- Update to version 0.5.4:
- Made some fixes to the memory management, because callbacks in TidyLib have
  changed. Thanks to Guenter Knauf <gknauf@users.sourceforge.net>
  for contributing the patch.
- Added Apache conf files
- Added Microsoft Developer Studio Project File for Win32,
  thanks to Guenter Knauf <gknauf@users.sourceforge.net> for contributing.
- Added Novell Netware Makefile,
  thanks to Guenter Knauf <gknauf@users.sourceforge.net> for contributing.
* Mon Nov 28 2005 sierkb@gmx.de
- Generating also a debug information sub-package.
* Tue Nov 22 2005 sierkb@gmx.de
- SUSE addons are now comprised in a Tarball instead of spread files.
- Rebuild for SUSE Linux 10.0 OSS (GCC 4.0.2).
* Thu Nov 10 2005 sierkb@gmx.de
- Short intermediate fix:
  - Changed HTTP Media Type of error page from 'application/xhtml+xml'
    to 'application/xml', respecting that Internet Explorer up to version 6
    doesn't recognize the 'true' XHTML Media Type but the default
    XML Media Type for applications.
    References:
    http://www.w3.org/TR/xhtml-mediatypes (XHTML Media Types),
    RFC 3023 (The 'application/xml' Media Type),
    RFC 3236 (The 'application/xhtml+xml' Media Type).
  - Added HTTP charset parameter to HTTP Media Type as recommended
    in the W3C note and the RFCs mentioned above.
* Tue Nov  1 2005 sierkb@gmx.de
- Removed copyright notice on error page footer.
- Changed error page from XHTML 1.0 to XHTML 1.1 and its Content-Type
  from 'text/html' to 'application/xhtml+xml'.
- Fixed Typo.
* Mon Oct 31 2005 sierkb@gmx.de
- Updated tidy source to the latest version 051027.
- Updated tidy docs to the latest version 051021.
* Wed Oct 26 2005 sierkb@gmx.de
- Update to version 0.5.3:
  - Added Base64 image and shortcut icon to the error page.
- APR Build macro: search for TidyLib headers in /usr/include/tidy.
- Improved Spec file.
* Sun Oct 16 2005 sierkb@gmx.de
- Updated tidy to version 051014.
* Mon Oct 10 2005 sierkb@gmx.de
- Update to version 0.5.2:
  - Improved and beautified mod_tidy.c:
  - moved some declarations into new header file mod_tidy.h
* Tue Sep 27 2005 sierkb@gmx.de
- Update to version 0.5.1:
  - Styled error log similar to the style of the W3C Markup Validation Service.
  - Fixed some little unclean written code which caused several warnings:
  - removed unused variables;
  - added prototypes for mod_tidy_FatalError, mod_tidy_MemAlloc,
    mod_tidy_MemFree and mod_tidy_MemRealloc.
* Mon Sep 19 2005 sierkb@gmx.de
- Updated tidy to version 050913.
* Sun Jul 24 2005 sierkb@gmx.de
- Updated tidy to version 050723.
- Updated Source-URL.
* Wed Jul 13 2005 sierkb@gmx.de
- Update to version 0.5.
- Updated license, source URL, summary and description text.
* Mon May 23 2005 sierkb@gmx.de
- Initial build for SuSE Linux.
